@@ -1,4 +1,9 @@
-from dataclasses import dataclass
+from typing import Any, TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from dataclasses import dataclass
+else:
+    from zuper_typing import dataclass
 
 from .basics import InteractionProtocol
 
@@ -26,8 +31,10 @@ with "commands".
 "episode_start" marks the beginning of an episode.  
 
     """.strip(),
-    inputs={"observations": object, "seed": int, "get_commands": GetCommands, "episode_start": EpisodeStart,},
-    outputs={"commands": object},
+    inputs={
+        "observations": Any, "seed": int, "get_commands": GetCommands, "episode_start": EpisodeStart,
+    },
+    outputs={"commands": Any},
     language="""
             in:seed? ;
             (   in:episode_start ; 
